@@ -1,8 +1,8 @@
 
 
 class OperationProfiler():
-    def start(self, profile):
+    def start(self, profile, context):
         raise NotImplementedError()
 
-    def stop(self, profile):
+    def stop(self, profile, context):
         raise NotImplementedError()
