@@ -7,7 +7,7 @@ from google.protobuf.json_format import MessageToJson
 import pprint
 
 import graphsignal
-from graphsignal.profilers.pytorch import profile_step
+from graphsignal.profilers.pytorch import profile_inference
 from graphsignal.proto import profiles_pb2
 from graphsignal.uploader import Uploader
 
@@ -29,7 +29,7 @@ class PyTorchProfilerTest(unittest.TestCase):
         graphsignal.shutdown()
 
     @patch.object(Uploader, 'upload_profile')
-    def test_profile_step(self, mocked_upload_profile):
+    def test_profile_inference(self, mocked_upload_profile):
         x = torch.arange(-5, 5, 0.1).view(-1, 1)
         y = -5 * x + 0.1 * torch.randn(x.size())
         model = torch.nn.Linear(1, 1)
@@ -37,16 +37,11 @@ class PyTorchProfilerTest(unittest.TestCase):
             x = x.to('cuda:0')
             y = y.to('cuda:0')
             model = model.to('cuda:0')
-        criterion = torch.nn.MSELoss()
-        optimizer = torch.optim.SGD(model.parameters(), lr=0.1)
 
-        with profile_step('training' , effective_batch_size=128, ensure_profile=True):
+        with profile_inference(batch_size=128):
             y1 = model(x)
-            loss = criterion(y1, y)
-            optimizer.zero_grad()
-            loss.backward()
-            optimizer.step()
 
+        graphsignal.upload()
         profile = mocked_upload_profile.call_args[0][0]
 
         #pp = pprint.PrettyPrinter()
@@ -56,14 +51,13 @@ class PyTorchProfilerTest(unittest.TestCase):
             profile.frameworks[0].type,
             profiles_pb2.FrameworkInfo.FrameworkType.PYTORCH_FRAMEWORK)
 
-        self.assertEqual(profile.phase_name, 'training')
-        self.assertEqual(profile.step_stats.step_count, 1)
-        self.assertTrue(profile.step_stats.total_time_us > 0)
-        self.assertEqual(profile.step_stats.sample_count, 128)
+        self.assertEqual(profile.inference_stats.inference_count, 1)
+        self.assertTrue(profile.inference_stats.total_time_us > 0)
+        self.assertEqual(profile.inference_stats.sample_count, 128)
 
         test_op_stats = None
         for op_stats in profile.op_stats:
-            if op_stats.op_name == 'aten::mse_loss':
+            if op_stats.op_name == 'aten::addmm':
                 test_op_stats = op_stats
                 break
         self.assertIsNotNone(test_op_stats)
